@@ -81,7 +81,7 @@ function(liste_fonds,chemin_fonds,nom_projet,titre,titre2,sourc,colEntree,colSor
         remplissagefond="no"
       }
       
-      if (l[i] %in% c("fond_maille","fond_departement","fond_region","fond_pays"))
+      if (l[i] %in% c("fond_maille","fond_departement","fond_region","fond_pays","fond_etranger"))
       {
         couleurbordure="128,128,128"
       }else if (l[i]=="fond_territoire")
@@ -96,7 +96,7 @@ function(liste_fonds,chemin_fonds,nom_projet,titre,titre2,sourc,colEntree,colSor
       }
       
       stylebordure="solid"
-      if (l[i] %in% c("fond_flux_entree","fond_flux_sortie","fond_flux_leg","fond_maille","fond_departement","fond_pays","fond_territoire"))
+      if (l[i] %in% c("fond_flux_entree","fond_flux_sortie","fond_flux_leg","fond_maille","fond_departement","fond_pays","fond_etranger","fond_territoire"))
       {
         epaisseurbordure=0.26
       }else
